#!/bin/sh

tiphome=$1
tipadmin=$2
tippass=$3
ifix=tip2x_PI27417
ifix_file=PI27417.zip
ihome=`pwd`

error_exit() {
   echo
   echo "TIP IFIX install did not complete successfully."
   echo
   exit 1
}

error_usage() {
   echo
   echo "Usage: install_ifix.bat TIP_HOME TIP_ADMIN TIP_ADMIN_PASSWORD"
   echo "Example: install_ifix.bat /opt/IBM/tivoli/tipv2 tipadmin tippass"
   error_exit
}

error_tiphome() {
   echo
   echo "Error: $tiphome is not a valid 2.x TIP install location."
   echo "Example: install_ifix.bat /opt/IBM/tivoli/tipv2"
   error_exit
}

error_tipserver() {
   echo
   echo "The TIP Server must be stopped before the IFIX can be installed."
   error_exit
}

error_ifix_installed() {
   echo
   echo "Error: IFIX $ifix has already been installed."
   error_exit
}

error_backup() {
   echo
   echo "Error: Backing up old files failed."
   error_exit
}

error_install() {
  echo
  echo "Error: Installing new files failed."
  error_exit
}

echo 
echo "******************************************************************"
echo "     Tivoli Integrated Portal IFIX $ifix Installation "
echo "******************************************************************"
echo 

if [ $# != 3 ]; then
  error_usage
fi

if [ ! -d "$tiphome" ]; then
  error_tiphome
fi

echo "Checking for a valid TIP 2.x installation..."
props="$tiphome/profiles/TIPProfile/installedApps/TIPCell/isc.ear/isclite.war/WEB-INF/config/isc.version.properties"
if [ ! -f "$props" ]; then
  error_tiphome
fi
awk '/isc.version=2.2|isc.version=2.2.0.1|isc.version=2.2.0.3|isc.version=2.2.0.5|isc.version=2.2.0.7|isc.version=2.2.0.9|isc.version=2.2.0.11|isc.version=2.2.0.13/' "$props" >/dev/null 2>&1
if [ "$?" != "0" ]; then
  error_tiphome
fi

echo "Checking to see if the TIP server has been stopped..."
"$tiphome/profiles/TIPProfile/bin/serverStatus.sh"  server1 -user "$tipadmin" -password "$tippass"  | grep ADMU0509I >/dev/null 2>&1
if [ "$?" != "0" ]; then
  error_tipserver
fi

echo "Checking to see if this IFIX has already been installed..."
if [ -f "$tiphome/properties/ifixes/$ifix" ]; then
  error_ifix_installed
fi

if [ ! -d "$tiphome/properties/ifixes" ]; then
  mkdir "$tiphome/properties/ifixes"
fi

echo "Backing up old files..."
file1="$tiphome/profiles/TIPProfile/installedApps/TIPCell/isc.ear/isclite.war/WEB-INF/lib/isclite_jsp.jar"
echo "   Copying $file1 to $file1.$ifix"
cp "$file1" "$file1.$ifix"
if [ $? != "0" ]; then
  error_backup
fi


echo "Installing new files..."
cp "$ifix_file" "$tiphome"
if [ $? != "0" ]; then
  error_install
fi

cd "$tiphome"

"$tiphome/java/bin/jar" xvf "./$ifix_file"  
if [ $? != "0" ]; then
  rm "./$iix_file" >/dev/null 2>&1
  cd "$ihome"
  error_install
fi

echo "Updating isclite_jsp.jar..."

"$tiphome/java/bin/jar" uvf "$file1" _ibmjsp/html/isclite/*.class
if [ $? != "0" ]; then
  rm -rf "$tiphome/com"  >/dev/null 2>&1
  cd "$ihome"
  error_install
fi

  

rm -rf "$tiphome/_ibmjsp"  >/dev/null 2>&1


rm "./$ifix_file" >/dev/null 2>&1
cd "$ihome"

if [ ! -d "$tiphome/properties/ifixes" ]; then
  mkdir "$tiphome/properties/ifixes"
fi

date > "$tiphome/properties/ifixes/$ifix"

echo
echo "TIP IFIX install finished successully."
echo
